Index: src/arm/code-stubs-arm.cc |
diff --git a/src/arm/code-stubs-arm.cc b/src/arm/code-stubs-arm.cc |
index 664abe027190dd251397031a042a756fab6fd55b..0d8f3bd916d8b0f3f6e7b018b0eb408776c40258 100644 |
--- a/src/arm/code-stubs-arm.cc |
+++ b/src/arm/code-stubs-arm.cc |
@@ -1076,9 +1076,8 @@ void CEntryStub::Generate(MacroAssembler* masm) { |
__ mov(fp, Operand(pending_handler_fp_address)); |
__ ldr(fp, MemOperand(fp)); |
- // If the handler is a JS frame, restore the context to the frame. |
- // (kind == ENTRY) == (fp == 0) == (cp == 0), so we could test either fp |
- // or cp. |
+ // If the handler is a JS frame, restore the context to the frame. Note that |
+ // the context will be set to (cp == 0) for non-JS frames. |
__ cmp(cp, Operand(0)); |
__ str(cp, MemOperand(fp, StandardFrameConstants::kContextOffset), ne); |
@@ -1181,7 +1180,7 @@ void JSEntryStub::Generate(MacroAssembler* masm) { |
handler_offset_ = handler_entry.pos(); |
// Caught exception: Store result (exception) in the pending exception |
// field in the JSEnv and return a failure sentinel. Coming in here the |
// fp will be invalid because the PushTryHandler below sets it to 0 to |
// signal the existence of the JSEntry frame. |
__ mov(ip, Operand(ExternalReference(Isolate::kPendingExceptionAddress, |
isolate()))); |
@@ -1190,11 +1189,10 @@ void JSEntryStub::Generate(MacroAssembler* masm) { |
__ LoadRoot(r0, Heap::kExceptionRootIndex); |
__ b(&exit); |
- // Invoke: Link this frame into the handler chain. There's only one |
- // handler block in this code object, so its index is 0. |
+ // Invoke: Link this frame into the handler chain. |
__ bind(&invoke); |
// Must preserve r0-r4, r5-r6 are available. |
- __ PushTryHandler(StackHandler::JS_ENTRY, 0); |
+ __ PushStackHandler(); |
// If an exception not caught by another handler occurs, this handler |
// returns control to the code after the bl(&invoke) above, which |
// restores all kCalleeSaved registers (including cp and fp) to their |
@@ -1231,7 +1229,7 @@ void JSEntryStub::Generate(MacroAssembler* masm) { |
__ Call(ip); |
// Unlink this frame from the handler chain. |
- __ PopTryHandler(); |
+ __ PopStackHandler(); |
__ bind(&exit); // r0 holds result |
// Check if the current stack frame is marked as the outermost JS frame. |
@@ -1181,7 +1180,7 @@ void JSEntryStub::Generate(MacroAssembler* masm) { |
// Caught exception: Store result (exception) in the pending exception |
// field in the JSEnv and return a failure sentinel. Coming in here the |
- // fp will be invalid because the PushTryHandler below sets it to 0 to |
+ // fp will be invalid because the PushStackHandler below sets it to 0 to |
// signal the existence of the JSEntry frame. |
__ mov(ip, Operand(ExternalReference(Isolate::kPendingExceptionAddress, |